Python: module excerpts.op

excerpts.op | index /home/qwer/git/cyclops/fvafrcu/excerpts/excerpts/op.py

`@file
operating system functions`

Modules
`` |  |
excerpts.main | os | subprocess |

Functions
`` |  | is_tool(name) `Test if a Program is Installed Will raise an error if the programm is not found. Kwargs: name: The name of the program to be tested for. Returns: True if the Program is installed.` pandoc(file_name, compile_latex=False, formats='tex') `Run Pandoc on a File file_name: The file on which to run pandoc. formats: The pandoc output formats to be used. compile_latex: Compile the LaTeX file? Returns: 0 if parsing was successful, 1 otherwise.`

Data
`` |  | print_function = _Feature((2, 6, 0, 'alpha', 2), (3, 0, 0, 'alpha', 0), 65536)